@@ -37,7 +37,7 @@
 #include <libzvt/libzvt.h>
 
 static void zvt_background_set(ZvtTerm *term);
-static void zvt_configure_window(GtkWidget *widget, GdkEventConfigure *event, ZvtTerm *term);
+static gboolean zvt_configure_window(GtkWidget *widget, GdkEventConfigure *event, ZvtTerm *term);
 static void zvt_background_set_translate(ZvtTerm *term);
 
 #define d(x)
@@ -89,15 +89,15 @@ pixbuf_from_atom(GdkWindow *win, GdkAtom pmap)
 
   pp = pixmap_from_atom(win, pmap);
   if (pp) {
-    gdk_window_get_size(pp, &pwidth, &pheight);
+    gdk_drawable_get_size(pp, &pwidth, &pheight);
     pb = gdk_pixbuf_get_from_drawable(NULL,
 				      pp,
-				      gdk_window_get_colormap(win),
+				      gdk_drawable_get_colormap(win),
 				      0, 0, 0, 0,
 				      pwidth, pheight);
     /* Theoretically this should not destroy the pixmap on X, otherwise
      * we'll need another hack like pixmap_free_atom */
-    gdk_pixmap_unref(pp);
+    g_object_unref(pp);
     return pb;
   }
   return NULL;
@@ -195,7 +195,7 @@ add_winwatch(GdkWindow *win, GdkAtom atom, void *callback, void *data)
   }
   w = g_malloc0(sizeof(*w));
   vt_list_new(&w->watchlist);
-  gdk_window_ref(win);
+  g_object_ref(win);
   w->win = win;
   w->propmask = gdk_window_get_events(win);
   gdk_window_add_filter(win, zvt_filter_prop_change, w);
@@ -234,7 +234,7 @@ del_winwatch(GdkWindow *win, void *data)
     if (vt_list_empty(&w->watchlist)) {
       gdk_window_set_events(w->win, w->propmask);
       gdk_window_remove_filter(w->win, zvt_filter_prop_change, w);
-      gdk_window_unref(w->win);
+      g_object_unref(w->win);
       vt_list_remove((struct vt_listnode *)w);
       g_free(w);
     }
@@ -249,17 +249,17 @@ zvt_watch_move(ZvtTerm *term)
   struct _zvtprivate *zp = _ZVT_PRIVATE(term);
 
   zp->background_watchsig =
-    gtk_signal_connect(GTK_OBJECT (gtk_widget_get_toplevel(GTK_WIDGET(term))),
-		       "configure_event",
-		       GTK_SIGNAL_FUNC(zvt_configure_window),
-		       GTK_OBJECT(term));
+    g_signal_connect(G_OBJECT (gtk_widget_get_toplevel(GTK_WIDGET(term))),
+		     "configure_event",
+		     G_CALLBACK(zvt_configure_window),
+		     G_OBJECT(term));
 }
 
 static void
 zvt_unwatch_move(ZvtTerm *term)
 {
   struct _zvtprivate *zp = _ZVT_PRIVATE(term);
-  gtk_signal_disconnect(GTK_OBJECT (gtk_widget_get_toplevel(GTK_WIDGET(term))), zp->background_watchsig);
+  g_signal_handler_disconnect(G_OBJECT (gtk_widget_get_toplevel(GTK_WIDGET(term))), zp->background_watchsig);
 }
 
 /*
@@ -334,27 +334,27 @@ zvt_term_background_set_pixmap(struct zvt_background *b, GdkPixmap *p, GdkColorm
   case ZVT_BGTYPE_NONE:		/* no background */
     break;
   case ZVT_BGTYPE_ATOM:		/* pixmap id contained in atom */
-    gdk_window_unref(b->data.atom.window);
+    g_object_unref(b->data.atom.window);
     break;
   case ZVT_BGTYPE_PIXMAP:	/* normal pixmap */
     if (b->data.pixmap.pixmap)
-      gdk_pixmap_unref(b->data.pixmap.pixmap);
+      g_object_unref(b->data.pixmap.pixmap);
     if (b->data.pixmap.cmap)
-      gdk_colormap_unref(b->data.pixmap.cmap);
+      g_object_unref(b->data.pixmap.cmap);
     break;
   case ZVT_BGTYPE_FILE:		/* file */
     g_free(b->data.pixmap_file);
     break;
   case ZVT_BGTYPE_PIXBUF:		/* pixbuf */
-    gdk_pixbuf_unref(b->data.pixbuf);
+    g_object_unref(b->data.pixbuf);
     break;
   }
   b->data.pixmap.pixmap = p;
   if (p)
-    gdk_pixmap_ref(p);
+    g_object_ref(p);
   b->data.pixmap.cmap = cmap;
   if (cmap)
-    gdk_colormap_ref(cmap);
+    g_object_ref(cmap);
   b->type = ZVT_BGTYPE_PIXMAP;
 }
 
@@ -373,7 +373,7 @@ zvt_term_background_set_pixmap_atom(struct zvt_background *b, GdkWindow *win, Gd
 {
   zvt_term_background_set_pixmap(b, 0, 0);
   b->data.atom.atom = atom;
-  gdk_window_ref(win);
+  g_object_ref(win);
   b->data.atom.window = win;
   b->type = ZVT_BGTYPE_ATOM;
 }
@@ -405,7 +405,7 @@ void
 zvt_term_background_set_pixbuf(struct zvt_background *b, GdkPixbuf *pb)
 {
   zvt_term_background_set_pixmap(b, 0, 0);
-  gdk_pixbuf_ref(pb);
+  g_object_ref(pb);
   b->data.pixbuf = pb;
   b->type = ZVT_BGTYPE_PIXBUF;
 }
@@ -675,7 +675,7 @@ zvt_background_set(ZvtTerm *term)
     int width, height;
     if (pixbuf==NULL && pixmap!=NULL) {
       int pwidth, pheight;
-      gdk_window_get_size(pixmap, &pwidth, &pheight);
+      gdk_drawable_get_size(pixmap, &pwidth, &pheight);
       pixbuf = gdk_pixbuf_get_from_drawable(0, pixmap, cmap, 0, 0, 0, 0, pwidth, pheight);
       /* free the pixmap? */
     }
@@ -707,7 +707,7 @@ zvt_background_set(ZvtTerm *term)
       if (b->scale.type != ZVT_BGSCALE_NONE) {
         GdkPixbuf *tmp = gdk_pixbuf_scale_simple(pixbuf, width, height,
 						 GDK_INTERP_NEAREST);
-	gdk_pixbuf_unref(pixbuf);
+	g_object_unref(pixbuf);
 	pixbuf = tmp;
       }
     }
@@ -716,12 +716,6 @@ zvt_background_set(ZvtTerm *term)
   /* if we have a pixbuf, then we need to convert it to a pixmap to actually
      use it ... */
   if (pixbuf!=NULL) {
-    static int init=0;
-
-    if (!init) {
-      gdk_rgb_init();
-      init=1;
-    }
 
     pixmap = gdk_pixmap_new(GTK_WIDGET(term)->window,
 			    gdk_pixbuf_get_width(pixbuf),
@@ -734,7 +728,7 @@ zvt_background_set(ZvtTerm *term)
 				  GDK_RGB_DITHER_MAX,
 				  0, 0);
     /* free working area */
-    gdk_pixbuf_unref(pixbuf);
+    g_object_unref(pixbuf);
   }
 
   zp->background_pixmap = pixmap;
@@ -782,7 +776,7 @@ zvt_background_set_translate(ZvtTerm *term)
  * If we configure window, work out if we have to reload the background
  * image, etc.
  */
-static void
+static gboolean
 zvt_configure_window(GtkWidget *widget, GdkEventConfigure *event, ZvtTerm *term)
 {
   struct _zvtprivate *zp = _ZVT_PRIVATE(term);
@@ -797,7 +791,7 @@ zvt_configure_window(GtkWidget *widget, GdkEventConfigure *event, ZvtTerm *term)
 			 0, 0,
 			 &x, &y,
 			 &childret);
-  gdk_window_get_size(GTK_WIDGET(term)->window, &width, &height);
+  gdk_drawable_get_size(GTK_WIDGET(term)->window, &width, &height);
 
   d(printf("configure event, pos %d,%d size %d-%d\n", x, y, width, height));
   d(printf("last was at %d,%d %d-%d\n", b->pos.x, b->pos.y, b->pos.w, b->pos.h));
@@ -827,5 +821,7 @@ zvt_configure_window(GtkWidget *widget, GdkEventConfigure *event, ZvtTerm *term)
   }
 
   d(printf("we moved/sized\n"));
+
+  return FALSE;
 }
 
